Changelog
=========

1.5.0 (2024-06-25)
------------------
* Using ``qtpy`` library instead of my own Qt5/6 mechanism

1.4.0 (2023-03-20)
------------------
* Adjusted the `SS_GROUPBOX` stylesheet: Groupbox title is now vertically
  aligned to be centered with the top line, regardless of the Qt lib. Nothing
  changes for PyQt5/PySide2, and fixes PyQt6/PySide6.
* Added function `e8()` to calculate the pixel width that is necessary to fit
  `N` number of '8's in the supplied `font`. In analogy to the 'em' font-metric,
  but now focused on displaying numeric values.

1.3.0 (2023-02-27)
------------------
* Neater support for PyQt5, PyQt6, PySide2 and PySide6

1.2.0 (2022-09-13)
------------------
* Added support for PyQt5, PyQt6, PySide2 and PySide6

1.1.0 (2022-01-21)
------------------
* Vamped up styles conform `DvG_Arduino_lock-in_amp v2.0` project
* Added hover effects
* Added SS_GROUP_RECT, SS_HOVER & SS_TABS
* Added PyQtGraph color definitions

1.0.0 (2020-08-11)
------------------
* First release on PyPI
